@@ -7,4 +7,10 @@ ELEANOR_CACHE_DIR = ".eleanor/"
 CUTOUT_SIZE = 13
 MISSION_KEPLER = "Kepler"
 MISSION_K2 = "K2"
-MISSION_TESS = "TESS"
\ No newline at end of file
+MISSION_TESS = "TESS"
+SPOC_AUTHOR = "SPOC"
+ELEANOR_AUTHOR = "ELEANOR"
+TESS_SPOC_AUTHOR = "TESS-SPOC"
+MISSION_ID_KEPLER = "KIC"
+MISSION_ID_KEPLER_2 = "EPIC"
+MISSION_ID_TESS = "TIC"
\ No newline at end of file
