@@ -1,13 +1,10 @@
-import logging
 import os
 import unittest
 from lcbuilder.lcbuilder_class import LcBuilder
 from lcbuilder.objectinfo.InputObjectInfo import InputObjectInfo
-from lcbuilder.objectinfo.MissionFfiCoordsObjectInfo import MissionFfiCoordsObjectInfo
-from lcbuilder.objectinfo.MissionFfiIdObjectInfo import MissionFfiIdObjectInfo
 from lcbuilder.objectinfo.MissionInputObjectInfo import MissionInputObjectInfo
 from lcbuilder.objectinfo.MissionObjectInfo import MissionObjectInfo
-
+from lcbuilder import constants
 
 class TestsLcBuilder(unittest.TestCase):
     def test_build_object_info(self):
@@ -30,50 +27,54 @@ class TestsLcBuilder(unittest.TestCase):
         assert object_info.mission_id() is None and object_info.sherlock_id() == "25.9_-19.3_FFI_all"
         target_name = "25.9_-19.3"
         cadence = 120
-        try:
-            lcbuilder.build_object_info(target_name, None, sectors, file, cadence, None, None, None, None,
+        object_info = lcbuilder.build_object_info(target_name, None, sectors, file, cadence, None, None, None, None,
                                                   None)
-            assert False
-        except ValueError as e:
-            logging.info("Expected exception")
-            # Expected exception
+        assert object_info.mission_id() is None and object_info.sherlock_id() == "25.9_-19.3_FFI_all"
         target_name = "WHATEVER"
         file = "fake_lc.csv"
         object_info = lcbuilder.build_object_info(target_name, None, sectors, file, cadence, None, None, None, None, None)
         assert object_info.mission_id() is None and object_info.sherlock_id() == "INP_" + os.path.splitext(file)[0].replace("/", "_")
 
-
     def test_short_cadence(self):
-        lc_build = LcBuilder().build(MissionObjectInfo("TIC 352315023", 'all'), "./")
+        lc_build = LcBuilder().build(MissionObjectInfo('all', "TIC 352315023", cadence=120), "./")
         self.assertEqual(lc_build.cadence, 120)
         self.assertGreater(len(lc_build.lc), 0)
         self.__test_tess_star_params(lc_build.star_info)
 
     def test_short_cadence_kic(self):
-        lc_build = LcBuilder().build(MissionObjectInfo("KIC 12557548", 'all'), "./")
+        lc_build = LcBuilder().build(MissionObjectInfo('all', "KIC 12557548", cadence=60), "./")
         self.assertEqual(lc_build.cadence, 59)
         self.assertGreater(len(lc_build.lc), 0)
         self.__test_kepler_star_params(lc_build.star_info)
 
     def test_long_cadence_missing_star_kic(self):
-        lc_build = LcBuilder().build(MissionFfiIdObjectInfo("KIC 12106934", 'all'), "./")
+        lc_build = LcBuilder().build(MissionObjectInfo('all', "KIC 12106934", cadence=1800), "./")
         self.assertEqual(lc_build.cadence, 1765)
         self.assertGreater(len(lc_build.lc), 0)
 
     def test_short_cadence_epic(self):
-        lc_build = LcBuilder().build(MissionObjectInfo("EPIC 211945201", 'all'), "./")
+        lc_build = LcBuilder().build(MissionObjectInfo('all', "EPIC 211945201", cadence=60), "./")
         self.assertEqual(lc_build.cadence, 59)
         self.assertGreater(len(lc_build.lc), 0)
         self.__test_k2_star_params(lc_build.star_info)
 
     def test_long_cadence(self):
-        lc_build = LcBuilder().build(MissionFfiIdObjectInfo("TIC 352315023", 'all'), "./")
+        lc_build = LcBuilder().build(MissionObjectInfo('all', "TIC 352315023", cadence=600,
+                                                       author=constants.ELEANOR_AUTHOR), "./")
         self.assertEqual(lc_build.cadence, 600)
         self.assertGreater(len(lc_build.lc), 0)
         self.__test_tess_star_params(lc_build.star_info)
 
+    def test_long_cadence_other_author(self):
+        lc_build = LcBuilder().build(MissionObjectInfo('all', "TIC 192833836", cadence=600,
+                                                       author=constants.TESS_SPOC_AUTHOR), "./")
+        self.assertEqual(lc_build.cadence, 600)
+        self.assertGreater(len(lc_build.lc), 0)
+
     def test_long_cadence_coords(self):
-        lc_build = LcBuilder().build(MissionFfiCoordsObjectInfo(300.47, -71.96, 'all'), "./")
+        lc_build = LcBuilder().build(MissionObjectInfo('all', ra=300.47, dec=-71.96, cadence=600,
+                                                       author=constants.ELEANOR_AUTHOR),
+                                     "./")
         self.assertEqual(lc_build.cadence, 600)
         self.assertGreater(len(lc_build.lc), 0)
         self.__test_tess_star_params(lc_build.star_info)
@@ -125,24 +126,25 @@ class TestsLcBuilder(unittest.TestCase):
         self.assertAlmostEqual(star_info.dec, 19.402252, 3)
 
     def test_build(self):
-        lc_build = LcBuilder().build(MissionObjectInfo("TIC 352315023", [13]), "./")
-        self.assertEqual(18107, len(lc_build.lc))
-        self.assertEqual(20479, len(lc_build.lc_data))
-        lc_build = LcBuilder().build(MissionObjectInfo("KIC 12557548", [13]), "./")
-        self.assertEqual(127850, len(lc_build.lc))
-        self.assertEqual(130290, len(lc_build.lc_data))
-        lc_build = LcBuilder().build(MissionObjectInfo("EPIC 211945201", 'all'), "./")
-        self.assertEqual(107670, len(lc_build.lc))
-        self.assertEqual(116820, len(lc_build.lc_data))
-        lc_build = LcBuilder().build(MissionFfiIdObjectInfo("KIC 12557548", [1]), "./")
-        self.assertEqual(1543, len(lc_build.lc))
-        self.assertEqual(1639, len(lc_build.lc_data))
-        lc_build = LcBuilder().build(MissionFfiIdObjectInfo("EPIC 211945201", [5]), "./")
-        self.assertEqual(3324, len(lc_build.lc))
-        self.assertEqual(3663, len(lc_build.lc_data))
-        lc_build = LcBuilder().build(MissionFfiIdObjectInfo("TIC 352315023", [13]), "./")
+        lc_build = LcBuilder().build(MissionObjectInfo([13], "TIC 352315023", cadence=1800,
+                                                       author=constants.ELEANOR_AUTHOR), "./")
         self.assertEqual(1222, len(lc_build.lc))
         self.assertEqual(1320, len(lc_build.lc_data))
+        lc_build = LcBuilder().build(MissionObjectInfo([13], "TIC 352315023", cadence=120), "./")
+        self.assertEqual(18107, len(lc_build.lc))
+        self.assertEqual(20479, len(lc_build.lc_data))
+        lc_build = LcBuilder().build(MissionObjectInfo([13], "KIC 12557548", cadence=60), "./")
+        self.assertEqual(127850, len(lc_build.lc))
+        self.assertEqual(130290, len(lc_build.lc_data))
+        lc_build = LcBuilder().build(MissionObjectInfo('all', "EPIC 211945201", cadence=60), "./")
+        self.assertEqual(107670, len(lc_build.lc))
+        self.assertEqual(116820, len(lc_build.lc_data))
+        lc_build = LcBuilder().build(MissionObjectInfo([1], "KIC 12557548", cadence=1800), "./")
+        self.assertEqual(1543, len(lc_build.lc))
+        self.assertEqual(1639, len(lc_build.lc_data))
+        lc_build = LcBuilder().build(MissionObjectInfo([5], "EPIC 211945201", cadence=1800), "./")
+        self.assertEqual(3324, len(lc_build.lc))
+        self.assertEqual(3663, len(lc_build.lc_data))
 
     def test_binning(self):
         directory = os.path.dirname(__file__) + "/input.csv"
